.. _recipe_asr.projected_bandstructure:

asr.projected_bandstructure
===========================


.. contents:: Contents
   :local:

Summary
-------

This is the documentation for :py:mod:`asr.projected_bandstructure`-recipe.
This recipe is comprised of a single step, namely:

  - :py:func:`asr.projected_bandstructure.main`

Run this recipe through the CLI interface

.. code-block:: console

   $ asr run asr.projected_bandstructure

or as a python module

.. code-block:: console

   $ python -m asr.projected_bandstructure

Detailed description
--------------------
Orbital projected band structure.

Steps
-----


asr.projected_bandstructure
^^^^^^^^^^^^^^^^^^^^^^^^^^^
.. autofunction:: asr.projected_bandstructure.main
   